==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/is.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Tengiliðir",
    "Address book name" : "Heiti nafnaskrár",
    "Import" : "Flytja inn",
    "The selected image is too big (max 1MB)" : "Valin mynd er of stór (hám. 1MB)",
    "No contacts in here" : "Engir tengiliðir hér",
    "Name" : "Nafn",
    "Organization" : "Stofnun/félag",
    "Title" : "Titill",
    "Add field ..." : "Bæta við reit...",
    "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
    "Post office box" : "Pósthólf",
    "Postal code" : "Póstnúmer",
    "City" : "Borg",
    "State or province" : "Ríki eða fylki",
    "Country" : "Land",
    "Address" : "Slóð",
    "(new group)" : "(nýr hópur)",
    "Last name" : "Eftirnafn",
    "First name" : "Eiginnafn",
    "Additional names" : "Aukanöfn",
    "Prefix" : "Forskeyti",
    "Suffix" : "Viðskeyti",
    "All contacts" : "Allir tengiliðir",
    "Not grouped" : "Ekki hópað",
    "New contact" : "Nýr tengiliður",
    "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
    "No contacts in file. Only VCard files are allowed." : "Engir tengiliðir í skrá. Einungis er tekið við VCard-skrám.",
    "Nickname" : "Gælunafn",
    "Detailed name" : "Ítarlegt nafn",
    "Notes" : "Minnispunktar",
    "Website" : "Vefsvæði",
    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "Groups" : "Hópar",
    "Birthday" : "Afmælisdagur",
    "Email" : "Netfang",
    "Instant messaging" : "Snarskilaboð",
    "Phone" : "Sími",
    "Mobile" : "Farsími",
    "Fax" : "Fax",
    "Fax home" : "Heimafax",
    "Fax work" : "Vinnufax",
    "Pager" : "Símboði",
    "Voice" : "Raddskilaboð",
    "Social network" : "Samfélagsnet",
    "Settings" : "Stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/is.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Tengiliðir",
    "Download" : "Sækja",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "Delete" : "Eyða",
    "can edit" : "getur breytt",
    "Address book name" : "Heiti nafnaskrár",
    "Import" : "Flytja inn",
    "The selected image is too big (max 1MB)" : "Valin mynd er of stór (hám. 1MB)",
    "No contacts in here" : "Engir tengiliðir hér",
    "Name" : "Nafn",
    "Organization" : "Stofnun/félag",
    "Title" : "Titill",
    "Add field ..." : "Bæta við reit...",
    "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
    "Post office box" : "Pósthólf",
    "Postal code" : "Póstnúmer",
    "City" : "Borg",
    "State or province" : "Ríki eða fylki",
    "Country" : "Land",
    "Address" : "Slóð",
    "(new group)" : "(nýr hópur)",
    "Last name" : "Eftirnafn",
    "First name" : "Eiginnafn",
    "Additional names" : "Aukanöfn",
    "Prefix" : "Forskeyti",
    "Suffix" : "Viðskeyti",
    "All contacts" : "Allir tengiliðir",
    "Not grouped" : "Ekki hópað",
    "New contact" : "Nýr tengiliður",
    "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
    "No contacts in file. Only VCard files are allowed." : "Engir tengiliðir í skrá. Einungis er tekið við VCard-skrám.",
    "Nickname" : "Gælunafn",
    "Detailed name" : "Ítarlegt nafn",
    "Notes" : "Minnispunktar",
    "Website" : "Vefsvæði",
    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "Groups" : "Hópar",
    "Birthday" : "Afmælisdagur",
    "Email" : "Netfang",
    "Instant messaging" : "Snarskilaboð",
    "Phone" : "Sími",
    "Mobile" : "Farsími",
    "Fax" : "Fax",
    "Fax home" : "Heimafax",
    "Fax work" : "Vinnufax",
    "Pager" : "Símboði",
    "Voice" : "Raddskilaboð",
    "Social network" : "Samfélagsnet",
    "Settings" : "Stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
